@@ -72,6 +72,10 @@ StatusManager::StatusManager()
 
 	connect( Kopete::AccountManager::self(), SIGNAL(accountUnregistered(const Kopete::Account*)),
 	         this, SLOT(accountUnregistered(const Kopete::Account*)));
+
+	connect( Kopete::AccountManager::self(), SIGNAL(accountOnlineStatusChanged(Kopete::Account*,Kopete::OnlineStatus,Kopete::OnlineStatus)),
+		 this, SLOT(checkIdleTimer()));
+
 }
 
 StatusManager::~StatusManager()
@@ -322,6 +326,19 @@ void StatusManager::setGlobalStatusMessage( const Kopete::StatusMessage &statusM
 	config.writeEntry( "GlobalStatusMessage", d->globalStatusMessage.message() );
 	config.sync();
 
+	// Iterate each connected account, updating its status message but keeping the
+	// same onlinestatus.
+	QList<Kopete::Account*> accountList = Kopete::AccountManager::self()->accounts();
+	foreach ( Kopete::Account *account, accountList )
+	{
+		Kopete::Contact *self = account->myself();
+		bool isInvisible = self && self->onlineStatus().status() == Kopete::OnlineStatus::Invisible;
+		if ( self && account->isConnected() && !isInvisible )
+		{
+			account->setOnlineStatus ( self->onlineStatus(), statusMessage );
+		}
+	}
+
 	emit globalStatusChanged();
 }
 
@@ -429,7 +446,8 @@ bool StatusManager::globalAway()
 {
 	return ( d->globalStatusCategory == OnlineStatusManager::Away ||
 	         d->globalStatusCategory == OnlineStatusManager::ExtendedAway ||
-	         d->globalStatusCategory == OnlineStatusManager::Busy );
+	         d->globalStatusCategory == OnlineStatusManager::Busy ||
+	         d->globalStatusCategory == OnlineStatusManager::Offline );
 }
 
 void StatusManager::accountUnregistered( const Kopete::Account *account )
@@ -437,6 +455,22 @@ void StatusManager::accountUnregistered( const Kopete::Account *account )
 	d->autoAwayAccounts.removeAll( const_cast<Kopete::Account *>(account) );
 }
 
+void StatusManager::checkIdleTimer()
+{
+	// TODO: should we check for d->autoAwayAccounts to see whether to stop the timer?
+	Kopete::IdleTimer* idleTimer = Kopete::IdleTimer::self();
+	idleTimer->unregisterTimeout( this );
+
+	if(Kopete::AccountManager::self()->isAnyAccountConnected()) {
+		if ( Kopete::BehaviorSettings::self()->useAutoAway() ) {
+			if (Kopete::BehaviorSettings::self()->autoAwayAskAvailable())
+				idleTimer->registerTimeout( d->awayTimeout, this, SLOT(askAndSetActive()), SLOT(setAutoAway()) );
+			else
+				idleTimer->registerTimeout( d->awayTimeout, this, SLOT(setActive()), SLOT(setAutoAway()) );
+		}
+	}
+}
+
 void StatusManager::loadSettings()
 {
 	KConfigGroup config( KGlobal::config(), "Status Manager" );
@@ -459,15 +493,7 @@ void StatusManager::loadBehaviorSettings()
 	customStatusMessage.setMessage( Kopete::BehaviorSettings::self()->autoAwayCustomMessage() );
 	d->customStatusMessage = customStatusMessage;
 
-	Kopete::IdleTimer* idleTimer = Kopete::IdleTimer::self();
-	idleTimer->unregisterTimeout( this );
-	
-	if ( Kopete::BehaviorSettings::self()->useAutoAway() ) {
-		if (Kopete::BehaviorSettings::self()->autoAwayAskAvailable())
-			idleTimer->registerTimeout( d->awayTimeout, this, SLOT(askAndSetActive()), SLOT(setAutoAway()) );
-		else
-			idleTimer->registerTimeout( d->awayTimeout, this, SLOT(setActive()), SLOT(setAutoAway()) );
-	}
+	checkIdleTimer();
 }
 
 }
